@@ -365,12 +365,7 @@ static bool Internal_isType (SDL_IOStream *rw_ops, CFStringRef uti_string_to_tes
     }
 
     Sint64 start = SDL_TellIO(rw_ops);
-    CFDictionaryRef hint_dictionary = CreateHintDictionary(uti_string_to_test);
-    CGImageSourceRef image_source = CreateCGImageSourceFromIOStream(rw_ops, hint_dictionary);
-
-    if (hint_dictionary != NULL) {
-        CFRelease(hint_dictionary);
-    }
+    CGImageSourceRef image_source = CreateCGImageSourceFromIOStream(rw_ops, NULL);
 
     if (NULL == image_source) {
         // reset the file pointer
@@ -459,14 +454,16 @@ static SDL_Surface *LoadImageFromIOStream (SDL_IOStream *rw_ops, CFStringRef uti
     if (hint_dictionary != NULL)
         CFRelease(hint_dictionary);
 
-    if (NULL == image_source)
+    if (NULL == image_source) {
         return NULL;
+    }
 
     CGImageRef image_ref = CreateCGImageFromCGImageSource(image_source);
     CFRelease(image_source);
 
-    if (NULL == image_ref)
+    if (NULL == image_ref) {
         return NULL;
+    }
     SDL_Surface *sdl_surface = Create_SDL_Surface_From_CGImage(image_ref);
     CFRelease(image_ref);
 
@@ -479,14 +476,16 @@ static SDL_Surface* LoadImageFromFile (const char *file)
 
     image_source = CreateCGImageSourceFromFile(file);
 
-    if(NULL == image_source)
+    if (NULL == image_source) {
         return NULL;
+    }
 
     CGImageRef image_ref = CreateCGImageFromCGImageSource(image_source);
     CFRelease(image_source);
 
-    if (NULL == image_ref)
+    if (NULL == image_ref) {
         return NULL;
+    }
     SDL_Surface *sdl_surface = Create_SDL_Surface_From_CGImage(image_ref);
     CFRelease(image_ref);
     return sdl_surface;
